@@ -1,5 +1,7 @@
 # Distance
 from pyinterpolate.distance import calc_point_to_point_distance, calc_block_to_block_distance
+from pyinterpolate.distance import aggregate_cluster, ClusterDetector
+from pyinterpolate.distance import create_grid, points_to_grid
 
 # IDW
 from pyinterpolate.idw import inverse_distance_weighting
@@ -12,13 +14,13 @@ from pyinterpolate.io import read_block, read_csv, read_txt
 from pyinterpolate.kriging import kriging, ordinary_kriging, simple_kriging
 # Block
 from pyinterpolate.kriging import centroid_poisson_kriging, area_to_area_pk, area_to_point_pk
+# Indicator
+from pyinterpolate.kriging import IndicatorKriging
 
 # Pipelines
 # Excluded: multi_kriging (BlockToBlockKrigingComparison)
 # PK
 from pyinterpolate.pipelines import BlockFilter, smooth_blocks
-# Data
-from pyinterpolate.pipelines import download_air_quality_poland
 
 # Processing
 from pyinterpolate.processing import Blocks, PointSupport
@@ -33,6 +35,8 @@ from pyinterpolate.variogram import build_theoretical_variogram, TheoreticalVari
 from pyinterpolate.variogram import AggregatedVariogram
 # Deconvolution
 from pyinterpolate.variogram import Deconvolution
+# Indicator
+from pyinterpolate.variogram import IndicatorVariogramData, ExperimentalIndicatorVariogram, IndicatorVariograms
 
 # Viz
 from pyinterpolate.viz import interpolate_raster
